@@ -1,5 +1,5 @@
 ## git2r, R bindings to the libgit2 library.
-## Copyright (C) 2013-2018 The git2r contributors
+## Copyright (C) 2013-2021 The git2r contributors
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License, version 2,
@@ -14,18 +14,18 @@
 ## with this program; if not, write to the Free Software Foundation, Inc.,
 ## 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-library("git2r")
+library(git2r)
 
 ## For debugging
 sessionInfo()
 
 ## Create directory for repository in tempdir
-path <- tempfile(pattern="git2r-")
+path <- tempfile(pattern = "git2r-")
 dir.create(path)
 
 ## Create repository
-repo <- init(path)
-config(repo, user.name="Alice", user.email="alice@example.org")
+repo <- init(path, branch = "main")
+config(repo, user.name = "Alice", user.email = "alice@example.org")
 
 ## Add changes to repo
 writeLines("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
@@ -43,9 +43,9 @@ writeLines(c("Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do",
 add(repo, "test-1.txt")
 commit_2 <- commit(repo, "Second commit message")
 
-# Checkout master and merge
+# Checkout main and merge
 b <- branches(repo)
-checkout(b[sapply(b, "[", "name") == "master"][[1]], force=TRUE)
+checkout(b[sapply(b, "[", "name") == "main"][[1]], force = TRUE)
 m <- merge(b[sapply(b, "[", "name") == "test"][[1]])
 
 # Check merge
@@ -61,4 +61,4 @@ r <- reflog(repo)
 stopifnot(identical(r[[1]]$message, "merge test: Fast-forward"))
 
 ## Cleanup
-unlink(path, recursive=TRUE)
+unlink(path, recursive = TRUE)
